Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
arrakis/__init__.py | (no class) | 15 | 3 | 0 | 80.0%
arrakis/__main__.py | (no class) | 158 | 63 | 0 | 60.1%
arrakis/api.py | (no class) | 15 | 1 | 0 | 93.3%
arrakis/block.py | Time | 0 | 0 | 0 | 100.0%
arrakis/block.py | Freq | 1 | 0 | 0 | 100.0%
arrakis/block.py | Series | 12 | 7 | 0 | 41.7%
arrakis/block.py | SeriesBlock | 67 | 20 | 0 | 70.1%
arrakis/block.py | (no class) | 146 | 2 | 3 | 98.6%
arrakis/channel.py | Channel | 30 | 2 | 0 | 93.3%
arrakis/channel.py | (no class) | 36 | 2 | 2 | 94.4%
arrakis/client.py | Client | 63 | 4 | 0 | 93.7%
arrakis/client.py | (no class) | 31 | 0 | 0 | 100.0%
arrakis/constants.py | (no class) | 8 | 0 | 0 | 100.0%
arrakis/flight.py | RequestType | 0 | 0 | 0 | 100.0%
arrakis/flight.py | Request | 0 | 0 | 0 | 100.0%
arrakis/flight.py | RequestValidator | 13 | 0 | 0 | 100.0%
arrakis/flight.py | MultiEndpointStream | 45 | 6 | 0 | 86.7%
arrakis/flight.py | (no class) | 65 | 2 | 3 | 96.9%
arrakis/mux.py | OnDrop | 0 | 0 | 0 | 100.0%
arrakis/mux.py | MuxedData | 3 | 1 | 0 | 66.7%
arrakis/mux.py | Muxer | 45 | 22 | 0 | 51.1%
arrakis/mux.py | (no class) | 32 | 0 | 0 | 100.0%
arrakis/publish.py | Publisher | 54 | 4 | 48 | 92.6%
arrakis/publish.py | (no class) | 33 | 6 | 9 | 81.8%
Total |  | 872 | 145 | 65 | 83.4%

No items found using the specified filter.